package uk.ac.rhul.cs2800.model;

import java.util.ArrayList;
import java.util.List;
import uk.ac.rhul.cs2800.model.exception.NoGradeAvailableException;

/**
 * Represents a student with personal and academic information.
 */
public class Student {

  private Long id;
  private String grade;
  private String firstName;
  private String lastName;
  private String username;
  private String email;
  private List<Grade> grades = new ArrayList<>();
  private List<Module> modules = new ArrayList<>();

  /**
   * Represents a student with basic identifying information. Each student has a unique ID, personal
   * details, and contact information.
   */

  public Student(Long id, String firstName, String lastName, String username, String email) {
    this.id = id;
    this.firstName = firstName;
    this.lastName = lastName;
    this.username = username;
    this.email = email;
  }

  /**
   * Adds a grade to the student's list of grades.
   *
   * @param g the grade to add
   */

  public void addGrade(Grade g) {
    grades.add(g);
  }

  /**
   * Adds a grade to the student's list of grades.
   *
   * 
   */

  public Grade getGrade(Module m) throws NoGradeAvailableException {
    for (Grade grade : grades) {
      if (grade.getModule().equals(m)) {
        return grade;
      }
    }
    throw new NoGradeAvailableException("No grade available for module: " + m.getName());
  }

  /**
   * Adds a grade to the student's list of grades.
   *
   * @param m the grade to add
   */
  public void registerModule(Module m) {
    modules.add(m);
  }

  /**
   * 0 if grade is empty.
   */

  public float computeAverage() {
    if (grades.isEmpty()) {
      return 0;
    }
    int total = 0;
    for (Grade grade : grades) {
      total += grade.getScore();
    }
    return (float) total / grades.size();
  }



  public List<Module> getModules() {
    return modules;
  }

}
